@@ -27,10 +27,10 @@ from __future__ import unicode_literals
 import copy
 import operator
 from itertools import chain
+from collections import OrderedDict
 
 from . import message
 
-from .collections import OrderedDict
 from .message import Position
 from .utils import to_underscores
 
@@ -109,7 +109,9 @@ in contrast to the other create_type() functions."""
                        ctype=fundamental.ctype)
         if gtype_name == 'GHashTable':
             return Map(TYPE_ANY, TYPE_ANY, gtype_name=gtype_name)
-        elif gtype_name in ('GArray', 'GPtrArray', 'GByteArray'):
+        elif gtype_name == 'GByteArray':
+            return Array('GLib.ByteArray', TYPE_UINT8, gtype_name=gtype_name)
+        elif gtype_name in ('GArray', 'GPtrArray'):
             return Array('GLib.' + gtype_name[1:], TYPE_ANY,
                          gtype_name=gtype_name)
         elif gtype_name == 'GStrv':
@@ -200,6 +202,7 @@ class TypeUnknown(Type):
     def __init__(self):
         Type.__init__(self, _target_unknown=True)
 
+
 # Fundamental types, two special ones
 TYPE_NONE = Type(target_fundamental='none', ctype='void')
 TYPE_ANY = Type(target_fundamental='gpointer', ctype='gpointer')
@@ -307,8 +310,6 @@ type_names['int32_t'] = TYPE_INT32
 type_names['uint32_t'] = TYPE_UINT32
 type_names['int64_t'] = TYPE_INT64
 type_names['uint64_t'] = TYPE_UINT64
-# C99 stdbool
-type_names['bool'] = TYPE_BOOLEAN
 
 # A few additional GLib type aliases
 type_names['guchar'] = TYPE_UINT8
@@ -321,6 +322,8 @@ type_names['gssize'] = TYPE_SSIZE
 type_names['gintptr'] = TYPE_INTPTR
 type_names['guintptr'] = TYPE_UINTPTR
 type_names['gconstpointer'] = TYPE_ANY
+type_names['grefcount'] = TYPE_INT
+type_names['gatomicrefcount'] = TYPE_INT
 
 # We used to support these; continue to do so
 type_names['any'] = TYPE_ANY
